@@ -5,7 +5,7 @@ use namespace::autoclean;
 use Authen::CAS::Client;
 use Moose;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 
 has uri            => ( is => 'ro', isa => 'Str', required => 1 );
@@ -48,7 +48,7 @@ sub authenticate {
     $c->log->debug( 'Redirecting to CAS for service "'. $service. '"' )
       if $c->debug;
 
-    $c->res->redirect( $self->_login_uri( $service ) );
+    $c->res->redirect( $self->_login_uri( $service, $authinfo ) );
     die $Catalyst::DETACH;
   }
 
